/**************************************************************************

walk_propath.p -- For the propath, walk the files and directories
                  of that path for the file list to be compiled by 
                  api_compile.p.

$Id: walk_propath.p,v 1.4 2007/05/18 04:06:15 sauge Exp sauge $

$Log: walk_propath.p,v $
Revision 1.4  2007/05/18 04:06:15  sauge
Enable for Webspeed E4GL files

Revision 1.3  2007/05/18 03:24:49  sauge
Working

Revision 1.2  2007/05/18 03:07:23  sauge
Added check if propath begins with DLC.  If so, ignore that entry.
Added messages for a compile log.

Revision 1.1  2007/05/18 02:47:45  sauge
Initial revision


***************************************************************************/

/**************************************************************************/
/* We set our version control tag in a string so it flows into the r-code */
/**************************************************************************/

DEFINE VARIABLE RCS AS CHARACTER NO-UNDO.
ASSIGN RCS="$Id: walk_propath.p,v 1.4 2007/05/18 04:06:15 sauge Exp sauge $".

{compile_list.i}
{postfix.i}

DEFINE OUTPUT PARAMETER TABLE FOR FileList.

/**************************************************************************/
/* UNIX has a handy tool to find all our files called find.  If UNIX, we  */
/* simply use that tool as it is faster than the 4GL.                     */
/**************************************************************************/

IF OPSYS = "UNIX" THEN RUN find_by_unix.


/**************************************************************************/
/* The unix walk of the propath.                                          */
/**************************************************************************/

PROCEDURE find_by_unix:

  DEFINE VARIABLE cCurrentPropath AS CHARACTER NO-UNDO.
  DEFINE VARIABLE iCurrentPropath AS INTEGER NO-UNDO.
  DEFINE VARIABLE cText           AS CHARACTER NO-UNDO.
  DEFINE VARIABLE cCmd            AS CHARACTER NO-UNDO.
  DEFINE VARIABLE iOrder          AS INTEGER NO-UNDO.
  DEFINE VARIABLE cDLC            AS CHARACTER NO-UNDO.

  ASSIGN iOrder = 0
         cDLC = OS-GETENV("DLC").


  DO iCurrentPropath = 1 TO NUM-ENTRIES (PROPATH):

    /************************************************************/
    /* According to the compile script, this tool kit's PROPATH */
    /* will always be the first entry.  So skip that one.       */
    /************************************************************/
    
    /* IF iCurrentPropath = 1 THEN NEXT. */

    ASSIGN cCurrentPropath = ENTRY(iCurrentPropath, PROPATH)
           cCmd = "find " + cCurrentPropath
                + " -type f".

    /************************************************************/
    /* If our propath begins with DLC, we are not interested in */
    /* compiling these.                                         */
    /************************************************************/

    IF cCurrentPropath BEGINS cDLC THEN NEXT.

    PUT UNFORMATTED "Using command: " cCmd SKIP.

    INPUT THROUGH VALUE (cCmd).

    REPEAT:
     
      IMPORT UNFORMATTED cText.

      PUT UNFORMATTED "Checking " cText SKIP.

      IF CAN-DO(".p,.w,.htm,.html", PostFix(cText)) THEN DO:

        PUT UNFORMATTED "Adding " cText " To Compile List" SKIP.

        CREATE FileList.

        ASSIGN FileList.FileName = cText
               iOrder = iOrder + 1
               FileList.Order = iOrder.

      END. /* IF CAN-DO... */

    END. /* REPEAT */

    INPUT CLOSE.

  END. /* DO iCurrentPropath */

END. /* PROCEDURE find_by_unix */

